Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Handler ¶
type Handler struct {
// contains filtered or unexported fields
}
func NewHandler ¶
func NewHandler(opts HandlerOpts) (*Handler, error)
func (*Handler) ServeHTTP ¶
func (h *Handler) ServeHTTP(w ResponseWriter, req Request)
type HandlerOpts ¶
type HandlerOpts struct {
// DNSHandler is required.
DNSHandler dns_handler.Handler
// Path specifies the query endpoint. If it is empty, Handler
// will ignore the request path.
Path string
// SrcIPHeader specifies the header that contain client source address.
// "True-Client-IP" "X-Real-IP" "X-Forwarded-For" will parse automatically.
SrcIPHeader string
// Logger specifies the logger which Handler writes its log to.
// Default is a nop logger.
Logger *zap.Logger
}
func (*HandlerOpts) Init ¶
func (opts *HandlerOpts) Init() error
type ResponseWriter ¶
Click to show internal directories.
Click to hide internal directories.